@@ -44,29 +44,28 @@ class RedisSemaphore(AbstractSemaphore):
         current_time = str(time.time())
         redis_hash = str(key)
         redis_key = f'{redis_hash}_{current_time}'
-        await self._check_limit_connection(redis_hash, redis_key, concurrency_limit)
+        await self.acquire(redis_hash, redis_key, concurrency_limit)
         logger.debug(f"{redis_key} connection acquired")
         try:
             yield
         finally:
             logger.debug(f"{redis_key} connection released")
-            await self.context.redis.hdel(redis_hash, redis_key)
+            await self.release(redis_hash, redis_key)
 
-    async def _check_limit_connection(self, redis_hash: str, redis_key: str, concurrency_limit: int) -> None:
-        """
-        This method checked block.
+    async def acquire(self, hash_name: str, key: str, concurrency_limit: int) -> bool:
+        if not await self.locked(hash_name, key, concurrency_limit):
+            return True
 
-        The number of connections cannot be more than the set restrict ``concurrency_limit``.
+    async def release(self, hash_name: str, key: str) -> None:
+        await self.context.redis.hdel(hash_name, key)
 
-        If the resources are free, key ``redis_key`` is set to hash ``redis_hash``.  \
-        If all resources are blocked, the program waits until the resource is released.
-        :param redis_hash: str, the name of the hash in Redis.
-        :param redis_key: str, set field in the hash stored at key in Redis.
-        :param concurrency_limit: int, the number of restrict connections.
-        :return: None.
-        """
-        while await self.context.redis.hset_and_get_hlen(
-                redis_hash, redis_key, seconds=self.config.key_time_to_live_s
-        ) > concurrency_limit:
-            await self.context.redis.hdel(redis_hash, redis_key)
+    async def locked(self, hash_name: str, key: str, concurrency_limit: int) -> bool:
+        while await self._set_and_check_count(hash_name, key, concurrency_limit):
+            await self.context.redis.hdel(hash_name, key)
             await asyncio.sleep(self.config.sleep_time_s)
+        return False
+
+    async def _set_and_check_count(self, hash_name: str, key: str, concurrency_limit: int) -> bool:
+        return await self.context.redis.hset_and_get_hlen(
+            hash_name, key, seconds=self.config.key_time_to_live_s
+        ) > concurrency_limit
